@@ -9,14 +9,13 @@ import type { KubeConfig } from "@kubernetes/client-node";
 import { HttpError } from "@kubernetes/client-node";
 import type { Kubectl } from "../../main/kubectl/kubectl";
 import type { KubeconfigManager } from "../../main/kubeconfig-manager/kubeconfig-manager";
-import { loadConfigFromFile } from "../kube-helpers";
 import type { KubeApiResource, KubeResource } from "../rbac";
 import { apiResourceRecord, apiResources } from "../rbac";
 import type { VersionDetector } from "../../main/cluster-detectors/version-detector";
 import type { DetectorRegistry } from "../../main/cluster-detectors/detector-registry";
 import plimit from "p-limit";
 import type { ClusterState, ClusterRefreshOptions, ClusterMetricsResourceType, ClusterId, ClusterMetadata, ClusterModel, ClusterPreferences, ClusterPrometheusPreferences, UpdateClusterModel, KubeAuthUpdate, ClusterConfigData } from "../cluster-types";
-import { ClusterMetadataKey, initialNodeShellImage, ClusterStatus } from "../cluster-types";
+import { ClusterMetadataKey, initialNodeShellImage, ClusterStatus, clusterModelIdChecker, updateClusterModelChecker } from "../cluster-types";
 import { disposer, isDefined, isRequestError, toJS } from "../utils";
 import type { Response } from "request";
 import { clusterListNamespaceForbiddenChannel } from "../ipc/cluster";
@@ -25,6 +24,7 @@ import type { ListNamespaces } from "./list-namespaces.injectable";
 import assert from "assert";
 import type { Logger } from "../logger";
 import type { BroadcastMessage } from "../ipc/broadcast-message.injectable";
+import type { LoadConfigfromFile } from "../kube-helpers/load-config-from-file.injectable";
 
 export interface ClusterDependencies {
   readonly directoryForKubeConfigs: string;
@@ -37,6 +37,7 @@ export interface ClusterDependencies {
   createListNamespaces: (config: KubeConfig) => ListNamespaces;
   createVersionDetector: (cluster: Cluster) => VersionDetector;
   broadcastMessage: BroadcastMessage;
+  loadConfigfromFile: LoadConfigfromFile;
 }
 
 /**
@@ -237,9 +238,16 @@ export class Cluster implements ClusterModel, ClusterState {
     return this.preferences.defaultNamespace;
   }
 
-  constructor(private readonly dependencies: ClusterDependencies, model: ClusterModel, configData: ClusterConfigData) {
+  constructor(private readonly dependencies: ClusterDependencies, { id, ...model }: ClusterModel, configData: ClusterConfigData) {
     makeObservable(this);
-    this.id = model.id;
+
+    const { error } = clusterModelIdChecker.validate({ id });
+
+    if (error) {
+      throw error;
+    }
+
+    this.id = id;
     this.updateModel(model);
     this.apiUrl = configData.clusterServerUrl;
 
@@ -261,6 +269,12 @@ export class Cluster implements ClusterModel, ClusterState {
   @action updateModel(model: UpdateClusterModel) {
     // Note: do not assign ID as that should never be updated
 
+    const { error } = updateClusterModelChecker.validate(model, { allowUnknown: true });
+
+    if (error) {
+      throw error;
+    }
+
     this.kubeConfigPath = model.kubeConfigPath;
     this.contextName = model.contextName;
 
@@ -487,7 +501,7 @@ export class Cluster implements ClusterModel, ClusterState {
   }
 
   async getKubeconfig(): Promise<KubeConfig> {
-    const { config } = await loadConfigFromFile(this.kubeConfigPath);
+    const { config } = await this.dependencies.loadConfigfromFile(this.kubeConfigPath);
 
     return config;
   }
@@ -497,7 +511,7 @@ export class Cluster implements ClusterModel, ClusterState {
    */
   async getProxyKubeconfig(): Promise<KubeConfig> {
     const proxyKCPath = await this.getProxyKubeconfigPath();
-    const { config } = await loadConfigFromFile(proxyKCPath);
+    const { config } = await this.dependencies.loadConfigfromFile(proxyKCPath);
 
     return config;
   }
