@@ -5,9 +5,11 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { broadcastMessage } from "./ipc";
 
+export type BroadcastMessage = (channel: string, ...args: any[]) => Promise<void>;
+
 const broadcastMessageInjectable = getInjectable({
   id: "broadcast-message",
-  instantiate: () => broadcastMessage,
+  instantiate: (): BroadcastMessage => broadcastMessage,
   causesSideEffects: true,
 });
 
