@@ -19,6 +19,7 @@ export * from "./events.api";
 export * from "./horizontal-pod-autoscaler.api";
 export * from "./ingress.api";
 export * from "./job.api";
+export * from "./lease.api";
 export * from "./limit-range.api";
 export * from "./namespace.api";
 export * from "./network-policy.api";
@@ -34,6 +35,7 @@ export * from "./replica-set.api";
 export * from "./resource-quota.api";
 export * from "./role.api";
 export * from "./role-binding.api";
+export * from "./runtime-class.api";
 export * from "./secret.api";
 export * from "./self-subject-rules-reviews.api";
 export * from "./service.api";
