@@ -18,3 +18,9 @@ export class WrappedAbortController extends AbortController {
     });
   }
 }
+
+export function setTimeoutFor(controller: AbortController, timeout: number): void {
+  const handle = setTimeout(() => controller.abort(), timeout);
+
+  controller.signal.addEventListener("abort", () => clearTimeout(handle));
+}
