@@ -5,20 +5,20 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import isProductionInjectable from "./is-production.injectable";
 import normalizedPlatformInjectable from "./normalized-platform.injectable";
-import getAbsolutePathInjectable from "../path/get-absolute-path.injectable";
 import lensResourcesDirInjectable from "./lens-resources-dir.injectable";
+import joinPathsInjectable from "../path/join-paths.injectable";
 
 const bundledResourcesDirectoryInjectable = getInjectable({
   id: "bundled-resources-directory",
   instantiate: (di) => {
     const isProduction = di.inject(isProductionInjectable);
     const normalizedPlatform = di.inject(normalizedPlatformInjectable);
-    const getAbsolutePath = di.inject(getAbsolutePathInjectable);
+    const joinPaths = di.inject(joinPathsInjectable);
     const lensResourcesDir = di.inject(lensResourcesDirInjectable);
 
     return isProduction
       ? lensResourcesDir
-      : getAbsolutePath(lensResourcesDir, "binaries", "client", normalizedPlatform);
+      : joinPaths(lensResourcesDir, "binaries", "client", normalizedPlatform);
   },
 });
 
