@@ -9,7 +9,7 @@ import type { Injectable } from "@ogre-tools/injectable";
  * @deprecated use asLegacyGlobalForExtensionApi instead, and use proper implementations instead of "modifications".
  */
 export const asLegacyGlobalObjectForExtensionApiWithModifications = <
-  InjectableInstance extends InjectionTokenInstance,
+  InjectableInstance extends InjectionTokenInstance & object,
   InjectionTokenInstance,
   ModificationObject extends object,
 >(
