@@ -5,12 +5,12 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { spawn } from "child_process";
 
+export type Spawn = typeof spawn;
+
 const spawnInjectable = getInjectable({
   id: "spawn",
 
-  instantiate: () => {
-    return spawn;
-  },
+  instantiate: (): Spawn => spawn,
   causesSideEffects: true,
 });
 
