@@ -6,19 +6,15 @@
 // Main process
 
 import * as Mobx from "mobx";
+import { spawn } from "node-pty";
 import * as LensExtensionsCommonApi from "../extensions/common-api";
 import * as LensExtensionsMainApi from "../extensions/main-api";
 import { getDi } from "./getDi";
 import startMainApplicationInjectable from "./start-main-application/start-main-application.injectable";
-import shouldStartHiddenInjectable from "./electron-app/features/should-start-hidden.injectable";
 
 const di = getDi();
 
-const shouldStartHidden = di.inject(shouldStartHiddenInjectable);
-
-const startApplication = di.inject(startMainApplicationInjectable);
-
-void startApplication(!shouldStartHidden);
+void di.inject(startMainApplicationInjectable);
 
 /**
  * Exports for virtual package "@k8slens/extensions" for main-process.
@@ -30,4 +26,8 @@ const LensExtensions = {
   Main: LensExtensionsMainApi,
 };
 
-export { Mobx, LensExtensions };
+const Pty = {
+  spawn,
+};
+
+export { Mobx, LensExtensions, Pty };
