@@ -9,6 +9,11 @@ import type { KubeconfigManagerDependencies } from "./kubeconfig-manager";
 import { KubeconfigManager } from "./kubeconfig-manager";
 import loggerInjectable from "../../common/logger.injectable";
 import lensProxyPortInjectable from "../lens-proxy/lens-proxy-port.injectable";
+import joinPathsInjectable from "../../common/path/join-paths.injectable";
+import getDirnameOfPathInjectable from "../../common/path/get-dirname.injectable";
+import deleteFileInjectable from "../../common/fs/delete-file.injectable";
+import pathExistsInjectable from "../../common/fs/path-exists.injectable";
+import writeFileInjectable from "../../common/fs/write-file.injectable";
 
 export interface KubeConfigManagerInstantiationParameter {
   cluster: Cluster;
@@ -24,6 +29,11 @@ const createKubeconfigManagerInjectable = getInjectable({
       directoryForTemp: di.inject(directoryForTempInjectable),
       logger: di.inject(loggerInjectable),
       lensProxyPort: di.inject(lensProxyPortInjectable),
+      joinPaths: di.inject(joinPathsInjectable),
+      getDirnameOfPath: di.inject(getDirnameOfPathInjectable),
+      deleteFile: di.inject(deleteFileInjectable),
+      pathExists: di.inject(pathExistsInjectable),
+      writeFile: di.inject(writeFileInjectable),
     };
 
     return (cluster) => new KubeconfigManager(dependencies, cluster);
