@@ -4,28 +4,20 @@
  */
 
 import logger from "../../../logger";
-import type WebSocket from "ws";
 import { Server as WebSocketServer } from "ws";
 import type { ProxyApiRequestArgs } from "../types";
 import type { ClusterManager } from "../../../cluster/manager";
 import URLParse from "url-parse";
-import type { Cluster } from "../../../../common/cluster/cluster";
 import type { ClusterId } from "../../../../common/cluster-types";
+import type { OpenShellSession } from "../../../shell-session/create-shell-session.injectable";
 
 interface Dependencies {
   authenticateRequest: (clusterId: ClusterId, tabId: string, shellToken: string | undefined) => boolean;
-
-  createShellSession: (args: {
-    websocket: WebSocket;
-    cluster: Cluster;
-    tabId: string;
-    nodeName?: string;
-  }) => { open: () => Promise<void> };
-
+  openShellSession: OpenShellSession;
   clusterManager: ClusterManager;
 }
 
-export const shellApiRequest = ({ createShellSession, authenticateRequest, clusterManager }: Dependencies) => ({ req, socket, head }: ProxyApiRequestArgs): void => {
+export const shellApiRequest = ({ openShellSession, authenticateRequest, clusterManager }: Dependencies) => ({ req, socket, head }: ProxyApiRequestArgs): void => {
   const cluster = clusterManager.getClusterForRequest(req);
   const { query: { node: nodeName, shellToken, id: tabId }} = new URLParse(req.url, true);
 
@@ -38,9 +30,7 @@ export const shellApiRequest = ({ createShellSession, authenticateRequest, clust
   const ws = new WebSocketServer({ noServer: true });
 
   ws.handleUpgrade(req, socket, head, (websocket) => {
-    const shell = createShellSession({ websocket, cluster, tabId, nodeName });
-
-    shell.open()
+    openShellSession({ websocket, cluster, tabId, nodeName })
       .catch(error => logger.error(`[SHELL-SESSION]: failed to open a ${nodeName ? "node" : "local"} shell`, error));
   });
 };
