@@ -3,9 +3,9 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { IpcRendererNavigationEvents } from "../../../renderer/navigation/events";
 import currentClusterFrameInjectable from "./current-cluster-frame/current-cluster-frame.injectable";
 import getCurrentApplicationWindowInjectable from "./application-window/get-current-application-window.injectable";
+import { reloadPageChannel } from "../../../features/navigation/reload-page/common/channel";
 
 const reloadCurrentApplicationWindowInjectable = getInjectable({
   id: "reload-current-application-window",
@@ -25,7 +25,7 @@ const reloadCurrentApplicationWindowInjectable = getInjectable({
 
       if (frameInfo) {
         lensWindow.send({
-          channel: IpcRendererNavigationEvents.RELOAD_PAGE,
+          channel: reloadPageChannel.id,
           frameInfo,
         });
       } else {
