@@ -14,9 +14,7 @@ const stopBroadcastingThemeChangeInjectable = getInjectable({
 
     return {
       id: "stop-broadcasting-theme-change",
-      run: async () => {
-        await broadcastThemeChange.stop();
-      },
+      run: () => void broadcastThemeChange.stop(),
     };
   },
 
