@@ -4,6 +4,7 @@
  */
 import type { EnvironmentVariables } from "./compute-shell-environment.injectable";
 import { getInjectable } from "@ogre-tools/injectable";
+import getBasenameOfPathInjectable from "../../../common/path/get-basename.injectable";
 import spawnInjectable from "../../child-process/spawn.injectable";
 import randomUUIDInjectable from "../../crypto/random-uuid.injectable";
 import loggerInjectable from "../../../common/logger.injectable";
@@ -11,7 +12,6 @@ import processExecPathInjectable from "./execPath.injectable";
 import processEnvInjectable from "./env.injectable";
 import { object } from "../../../common/utils";
 import type { AsyncResult } from "../../../common/utils/async-result";
-import { basename } from "path";
 
 export interface UnixShellEnvOptions {
   signal: AbortSignal;
@@ -54,6 +54,7 @@ const computeUnixShellEnvironmentInjectable = getInjectable({
     const cshLikeShellName = /^(t?csh)$/;
     const fishLikeShellName = /^fish$/;
 
+    const getBasenameOfPath = di.inject(getBasenameOfPathInjectable);
     const spawn = di.inject(spawnInjectable);
     const logger = di.inject(loggerInjectable);
     const randomUUID = di.inject(randomUUIDInjectable);
@@ -97,7 +98,7 @@ const computeUnixShellEnvironmentInjectable = getInjectable({
         ELECTRON_NO_ATTACH_CONSOLE: "1",
         TERM: "screen-256color-bce", // required for fish
       });
-      const shellName = basename(shellPath);
+      const shellName = getBasenameOfPath(shellPath);
       const { command, shellArgs, regex } = getShellSpecifices(shellName);
 
       logger.info(`[UNIX-SHELL-ENV]: running against ${shellPath}`, { command, shellArgs });
@@ -105,6 +106,7 @@ const computeUnixShellEnvironmentInjectable = getInjectable({
       return new Promise((resolve) => {
         const shellProcess = spawn(shellPath, shellArgs, {
           signal: opts.signal,
+          detached: true,
           env,
         });
         const stdout: Buffer[] = [];
