@@ -5,14 +5,11 @@
 
 import "@testing-library/jest-dom/extend-expect";
 import { fireEvent, screen, waitFor } from "@testing-library/react";
-import fse from "fs-extra";
 import React from "react";
 import type { ExtensionDiscovery } from "../../../../extensions/extension-discovery/extension-discovery";
 import type { ExtensionLoader } from "../../../../extensions/extension-loader";
 import { ConfirmDialog } from "../../confirm-dialog";
 import { Extensions } from "../extensions";
-import mockFs from "mock-fs";
-import { mockWindow } from "../../../../../__mocks__/windowMock";
 import { getDiForUnitTesting } from "../../../getDiForUnitTesting";
 import extensionLoaderInjectable from "../../../../extensions/extension-loader/extension-loader.injectable";
 import type { DiRender } from "../../test-utils/renderFor";
@@ -20,41 +17,28 @@ import { renderFor } from "../../test-utils/renderFor";
 import extensionDiscoveryInjectable from "../../../../extensions/extension-discovery/extension-discovery.injectable";
 import directoryForUserDataInjectable from "../../../../common/app-paths/directory-for-user-data/directory-for-user-data.injectable";
 import directoryForDownloadsInjectable from "../../../../common/app-paths/directory-for-downloads/directory-for-downloads.injectable";
-import getConfigurationFileModelInjectable from "../../../../common/get-configuration-file-model/get-configuration-file-model.injectable";
 import assert from "assert";
-import type { InstallFromInput } from "../install-from-input/install-from-input";
-import installFromInputInjectable from "../install-from-input/install-from-input.injectable";
+import type { InstallExtensionFromInput } from "../install-extension-from-input.injectable";
+import installExtensionFromInputInjectable from "../install-extension-from-input.injectable";
 import type { ExtensionInstallationStateStore } from "../../../../extensions/extension-installation-state-store/extension-installation-state-store";
 import extensionInstallationStateStoreInjectable from "../../../../extensions/extension-installation-state-store/extension-installation-state-store.injectable";
 import { observable, when } from "mobx";
-
-mockWindow();
-
-jest.setTimeout(30000);
-jest.mock("fs-extra");
-jest.mock("../../notifications");
-
-jest.mock("../../../../common/utils/downloadFile", () => ({
-  downloadFile: jest.fn(({ url }) => ({
-    promise: Promise.resolve(),
-    url,
-    cancel: () => {},
-  })),
-  downloadJson: jest.fn(({ url }) => ({
-    promise: Promise.resolve({}),
-    url,
-    cancel: () => { },
-  })),
-}));
-
-jest.mock("../../../../common/utils/tar");
+import type { DeleteFile } from "../../../../common/fs/delete-file.injectable";
+import deleteFileInjectable from "../../../../common/fs/delete-file.injectable";
+import type { DownloadJson } from "../../../../common/fetch/download-json.injectable";
+import type { DownloadBinary } from "../../../../common/fetch/download-binary.injectable";
+import downloadJsonInjectable from "../../../../common/fetch/download-json.injectable";
+import downloadBinaryInjectable from "../../../../common/fetch/download-binary.injectable";
 
 describe("Extensions", () => {
   let extensionLoader: ExtensionLoader;
   let extensionDiscovery: ExtensionDiscovery;
-  let installFromInput: jest.MockedFunction<InstallFromInput>;
+  let installExtensionFromInput: jest.MockedFunction<InstallExtensionFromInput>;
   let extensionInstallationStateStore: ExtensionInstallationStateStore;
   let render: DiRender;
+  let deleteFileMock: jest.MockedFunction<DeleteFile>;
+  let downloadJson: jest.MockedFunction<DownloadJson>;
+  let downloadBinary: jest.MockedFunction<DownloadBinary>;
 
   beforeEach(() => {
     const di = getDiForUnitTesting({ doGeneralOverrides: true });
@@ -62,17 +46,19 @@ describe("Extensions", () => {
     di.override(directoryForUserDataInjectable, () => "some-directory-for-user-data");
     di.override(directoryForDownloadsInjectable, () => "some-directory-for-downloads");
 
-    di.permitSideEffects(getConfigurationFileModelInjectable);
-
-    mockFs({
-      "some-directory-for-user-data": {},
-    });
-
     render = renderFor(di);
 
-    installFromInput = jest.fn();
+    installExtensionFromInput = jest.fn();
+    di.override(installExtensionFromInputInjectable, () => installExtensionFromInput);
 
-    di.override(installFromInputInjectable, () => installFromInput);
+    deleteFileMock = jest.fn();
+    di.override(deleteFileInjectable, () => deleteFileMock);
+
+    downloadJson = jest.fn().mockImplementation((url) => { throw new Error(`Unexpected call to downloadJson for url=${url}`); });
+    di.override(downloadJsonInjectable, () => downloadJson);
+
+    downloadBinary = jest.fn().mockImplementation((url) => { throw new Error(`Unexpected call to downloadJson for url=${url}`); });
+    di.override(downloadBinaryInjectable, () => downloadBinary);
 
     extensionLoader = di.inject(extensionLoaderInjectable);
     extensionDiscovery = di.inject(extensionDiscoveryInjectable);
@@ -95,10 +81,6 @@ describe("Extensions", () => {
     extensionDiscovery.uninstallExtension = jest.fn(() => Promise.resolve());
   });
 
-  afterEach(() => {
-    mockFs.restore();
-  });
-
   it("disables uninstall and disable buttons while uninstalling", async () => {
     extensionDiscovery.isLoaded = true;
 
@@ -123,7 +105,7 @@ describe("Extensions", () => {
     // Approve confirm dialog
     fireEvent.click(await screen.findByText("Yes"));
 
-    await waitFor(() => {
+    await waitFor(async () => {
       expect(extensionDiscovery.uninstallExtension).toHaveBeenCalled();
       fireEvent.click(menuTrigger);
       expect(screen.getByText("Disable")).toHaveAttribute("aria-disabled", "true");
@@ -137,9 +119,10 @@ describe("Extensions", () => {
     render(<Extensions />);
 
     const resolveInstall = observable.box(false);
+    const url = "https://test.extensionurl/package.tgz";
 
-    (fse.unlink as jest.MockedFunction<typeof fse.unlink>).mockReturnValue(Promise.resolve());
-    installFromInput.mockImplementation(async (input) => {
+    deleteFileMock.mockReturnValue(Promise.resolve());
+    installExtensionFromInput.mockImplementation(async (input) => {
       expect(input).toBe("https://test.extensionurl/package.tgz");
 
       const clear = extensionInstallationStateStore.startPreInstall();
@@ -152,13 +135,26 @@ describe("Extensions", () => {
       exact: false,
     }), {
       target: {
-        value: "https://test.extensionurl/package.tgz",
+        value: url,
       },
     });
 
+    const doResolve = observable.box(false);
+
+    downloadBinary.mockImplementation(async (targetUrl) => {
+      expect(targetUrl).toBe(url);
+
+      await when(() => doResolve.get());
+
+      return {
+        callWasSuccessful: false,
+        error: "unknown location",
+      };
+    });
+
     fireEvent.click(await screen.findByText("Install"));
     expect((await screen.findByText("Install")).closest("button")).toBeDisabled();
-    resolveInstall.set(true);
+    doResolve.set(true);
   });
 
   it("displays spinner while extensions are loading", () => {
