@@ -15,7 +15,6 @@ import { getInjectable } from "@ogre-tools/injectable";
 import commandOverlayInjectable from "../command-overlay.injectable";
 import createTerminalTabInjectable from "../../dock/terminal/create-terminal-tab.injectable";
 import type { DockTabCreate } from "../../dock/dock/store";
-import navigateToPreferencesInjectable from "../../../../common/front-end-routing/routes/preferences/navigate-to-preferences.injectable";
 import navigateToHelmChartsInjectable from "../../../../common/front-end-routing/routes/cluster/helm/charts/navigate-to-helm-charts.injectable";
 import navigateToHelmReleasesInjectable from "../../../../common/front-end-routing/routes/cluster/helm/releases/navigate-to-helm-releases.injectable";
 import navigateToConfigMapsInjectable from "../../../../common/front-end-routing/routes/cluster/config/config-maps/navigate-to-config-maps.injectable";
@@ -40,6 +39,9 @@ import navigateToCustomResourcesInjectable from "../../../../common/front-end-ro
 import navigateToEntitySettingsInjectable from "../../../../common/front-end-routing/routes/entity-settings/navigate-to-entity-settings.injectable";
 import getEntitySettingCommandsInjectable from "./get-entity-setting-commands.injectable";
 
+// TODO: Importing from features is not OK. Make commands to comply with Open Closed Principle to allow moving implementation under a feature
+import navigateToPreferencesInjectable from "../../../../features/preferences/common/navigate-to-preferences.injectable";
+
 export function isKubernetesClusterActive(context: CommandContext): boolean {
   return context.entity?.kind === "KubernetesCluster";
 }
